@@ -44,6 +44,8 @@ use App::Dochazka::Common;
 use App::Dochazka::REST;
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_up );
 use App::Dochazka::REST::Util qw( hash_the_password );
+use App::Dochazka::REST::Model::Activity;
+use App::Dochazka::REST::Model::Component;
 use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
 use App::Dochazka::REST::Model::Schedhistory qw( get_schedhistory );
 use App::Dochazka::REST::Model::Shared qw( noof select_single );
@@ -87,6 +89,7 @@ our @EXPORT = qw(
     create_testing_employee create_active_employee create_inactive_employee
     delete_testing_employee delete_employee_by_nick
     create_testing_activity delete_testing_activity
+    create_testing_component delete_testing_component
     create_testing_schedule delete_testing_schedule 
     gen_activity gen_employee gen_interval gen_lock
     gen_privhistory gen_schedhistory gen_schedule
@@ -531,6 +534,44 @@ sub delete_testing_activity {
 }
 
 
+=head2 create_testing_component
+
+Tests will need to set up and tear down testing components
+
+=cut
+
+sub create_testing_component {
+    my %PROPS = @_;  # must be at least path
+
+    my $comp = App::Dochazka::REST::Model::Component->spawn( \%PROPS );
+    is( ref($comp), 'App::Dochazka::REST::Model::Component', 'create_testing_component 1' );
+    my $status = $comp->insert( $faux_context );
+    if ( $status->not_ok ) {
+        BAIL_OUT( $status->code . " " . $status->text );
+    }
+    is( $status->level, "OK", 'create_testing_component 2' );
+    return $status->payload;
+}
+
+
+=head2 delete_testing_component
+
+Tests will need to set up and tear down testing components
+
+=cut
+
+sub delete_testing_component {
+    my $cid = shift;
+
+    my $status = App::Dochazka::REST::Model::Component->load_by_cid( $dbix_conn, $cid );
+    is( $status->level, 'OK', 'delete_testing_component 1' );
+    my $act = $status->payload;
+    $status = $act->delete( $faux_context );
+    is( $status->level, 'OK', 'delete_testing_component 2' );
+    return;
+}
+
+
 =head2 test_schedule_model
 
 Creates and returns a testing schedule without needing a L<Plack::Test> object.
